"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("debug"));
const interface_1 = require("./interface");
var LogOutput;
(function (LogOutput) {
    LogOutput[LogOutput["debug"] = 0] = "debug";
    LogOutput[LogOutput["silent"] = 1] = "silent";
})(LogOutput = exports.LogOutput || (exports.LogOutput = {}));
var LogTypes;
(function (LogTypes) {
    LogTypes["log"] = "log";
    LogTypes["debug"] = "debug";
    LogTypes["info"] = "info";
    LogTypes["warn"] = "warn";
    LogTypes["error"] = "error";
})(LogTypes = exports.LogTypes || (exports.LogTypes = {}));
class Logger {
    constructor(prefix) {
        const scopedPrefix = `framer:${prefix}`;
        const infoDebug = debug_1.default(scopedPrefix);
        infoDebug.log = console.log.bind(console);
        const errorDebug = debug_1.default(scopedPrefix);
        this.infoLogger = this.wrap(infoDebug);
        this.errorLogger = this.wrap(errorDebug);
    }
    static configure({ output = LogOutput.debug }) {
        Logger.config.output = output;
    }
    [LogTypes.debug](...args) {
        return this.infoLogger(...args);
    }
    [LogTypes.info](...args) {
        return this.infoLogger(...args);
    }
    [LogTypes.log](...args) {
        return this.infoLogger(...args);
    }
    [LogTypes.warn](...args) {
        return this.errorLogger(...args);
    }
    [LogTypes.error](...args) {
        return this.errorLogger(...args);
    }
    wrap(printer) {
        return (...args) => {
            if (!printer.enabled || Logger.config.output !== LogOutput.debug) {
                return;
            }
            if (interface_1.spinner.isSpinning) {
                interface_1.spinner.stop();
                printer(...args);
                interface_1.spinner.start();
            }
            else {
                printer(...args);
            }
        };
    }
}
exports.Logger = Logger;
Logger.config = {
    output: LogOutput.debug,
};
