"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["debug"] = 0] = "debug";
    LogLevel[LogLevel["info"] = 1] = "info";
    LogLevel[LogLevel["log"] = 2] = "log";
    LogLevel[LogLevel["warn"] = 3] = "warn";
    LogLevel[LogLevel["error"] = 4] = "error";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
var LogOutput;
(function (LogOutput) {
    LogOutput["console"] = "console";
    LogOutput["silent"] = "silent";
})(LogOutput = exports.LogOutput || (exports.LogOutput = {}));
var LogTypes;
(function (LogTypes) {
    LogTypes["debug"] = "debug";
    LogTypes["info"] = "info";
    LogTypes["log"] = "log";
    LogTypes["warn"] = "warn";
    LogTypes["error"] = "error";
})(LogTypes = exports.LogTypes || (exports.LogTypes = {}));
const globalConfig = {
    output: LogOutput.console,
    level: LogLevel.info,
};
const wrapLogger = (logger, level) => {
    return (...args) => {
        if (globalConfig.output === LogOutput.silent || level < globalConfig.level) {
            return;
        }
        logger(...args);
    };
};
exports.configureLogger = ({ output = globalConfig.output, level = globalConfig.level, }) => {
    globalConfig.output = output;
    globalConfig.level = level;
};
exports.createLogger = () => {
    /* tslint:disable:no-console */
    return {
        [LogTypes.debug]: wrapLogger(console.info, LogLevel.debug),
        [LogTypes.info]: wrapLogger(console.info, LogLevel.info),
        [LogTypes.log]: wrapLogger(console.log, LogLevel.log),
        [LogTypes.warn]: wrapLogger(console.warn, LogLevel.warn),
        [LogTypes.error]: wrapLogger(console.error, LogLevel.error),
    };
    /* tslint:enable:no-console */
};
