"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_1 = require("../../fs");
const entryLoader = function entryLoader(source) {
    const callback = this.async();
    const sourceString = Buffer.isBuffer(source) ? source.toString("utf8") : source;
    const packageJsonPath = path_1.default.join(this.rootContext, "package.json");
    const nodeModulesPath = path_1.default.join(this.rootContext, "node_modules");
    const yarnLockPath = path_1.default.join(this.rootContext, "yarn.lock");
    // We monitor yarn.lock as a depedency instead of package.json, relying on yarn
    // to trigger updates there.  Watching the node_modules is too expensive.
    this.addDependency(yarnLockPath);
    fs_1.readJSON(packageJsonPath).then((packageJson) => {
        const dependencies = new Set([
            "framer",
            ...Object.keys(packageJson.dependencies || {}),
            ...Object.keys(packageJson.devDependencies || {}),
        ]);
        const packagesInfoTemplate = [];
        for (const dependency of dependencies) {
            let dependencyPackageJson;
            if (!dependencyPackageJson) {
                // This is the path for a package that was installed from a registry
                const registryPackagePath = path_1.default.join(nodeModulesPath, dependency, "package.json");
                dependencyPackageJson = fs_1.readJSONSync(registryPackagePath);
            }
            let dependencyPath;
            if (packageJson.dependencies && packageJson.dependencies[dependency]) {
                dependencyPath = packageJson.dependencies[dependency];
            }
            else if (packageJson.devDependencies && packageJson.devDependencies[dependency]) {
                dependencyPath = packageJson.devDependencies[dependency];
            }
            if (!dependencyPackageJson && dependencyPath) {
                // This is the path for a package that was installed locally
                const localPackagePath = path_1.default.join(this.rootContext, dependencyPath, "package.json");
                dependencyPackageJson = fs_1.readJSONSync(localPackagePath);
            }
            if (dependencyPackageJson && dependencyPackageJson.framer && dependencyPackageJson.name) {
                const framerLoaderPrefix = dependency === "framer" ? "" : "framer-package-loader!";
                packagesInfoTemplate.push(`
                packages["${dependency}"] = () => {
                    var packageInfo = {}
                    var designJson
                    try {
                        packageInfo = require("${framerLoaderPrefix}${dependency}")
                        designJson = require("./designDependencies.js")["${dependency}"]
                    } catch (e) {
                        console.log(e)
                    }
                    packageInfo.__framer__ = packageInfo.__framer__ || {}
                    packageInfo.__framer__.packageJson = ${JSON.stringify(dependencyPackageJson)}
                    packageInfo.__framer__.packageJson.design = designJson
                    return packageInfo
                }`);
            }
        }
        const content = sourceString.replace(/__{PACKAGES}__/g, packagesInfoTemplate.join("\n"));
        callback(null, content);
    }, error => {
        callback(error);
    });
};
// eslint-disable-next-line import/no-default-export
exports.default = entryLoader;
