"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("debug"));
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["debug"] = 0] = "debug";
    LogLevel[LogLevel["info"] = 1] = "info";
    LogLevel[LogLevel["log"] = 2] = "log";
    LogLevel[LogLevel["warn"] = 3] = "warn";
    LogLevel[LogLevel["error"] = 4] = "error";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
var LogOutput;
(function (LogOutput) {
    LogOutput["debug"] = "debug";
    LogOutput["silent"] = "silent";
})(LogOutput = exports.LogOutput || (exports.LogOutput = {}));
var LogTypes;
(function (LogTypes) {
    LogTypes["debug"] = "debug";
    LogTypes["info"] = "info";
    LogTypes["log"] = "log";
    LogTypes["warn"] = "warn";
    LogTypes["error"] = "error";
})(LogTypes = exports.LogTypes || (exports.LogTypes = {}));
class Logger {
    constructor(prefix, enabled = true) {
        this._enabled = enabled;
        const scopedPrefix = `framer:build-library:${prefix}`;
        const infoDebug = debug_1.default(scopedPrefix);
        // eslint-disable-next-line no-console
        infoDebug.log = console.log.bind(console);
        const errorDebug = debug_1.default(scopedPrefix);
        // eslint-disable-next-line no-console
        errorDebug.log = console.error.bind(console);
        this[LogTypes.debug] = this.wrapLogger(infoDebug, LogLevel.debug);
        this[LogTypes.info] = this.wrapLogger(infoDebug, LogLevel.info);
        this[LogTypes.log] = this.wrapLogger(infoDebug, LogLevel.log);
        this[LogTypes.warn] = this.wrapLogger(errorDebug, LogLevel.warn);
        this[LogTypes.error] = this.wrapLogger(errorDebug, LogLevel.error);
    }
    get enabled() {
        return this._enabled;
    }
    set enabled(enabled) {
        this._enabled = enabled;
    }
    wrapLogger(logger, level) {
        return (...args) => {
            if (!this.enabled || Logger.config.output !== LogOutput.debug || level < Logger.config.level) {
                return;
            }
            logger(...args);
        };
    }
}
exports.Logger = Logger;
LogTypes.debug, LogTypes.info, LogTypes.log, LogTypes.warn, LogTypes.error;
Logger.config = {
    output: LogOutput.debug,
    level: LogLevel.info,
};
Logger.configure = ({ output = Logger.config.output, level = Logger.config.level, }) => {
    Logger.config.output = output;
    Logger.config.level = level;
};
