import { ProjectPaths } from "../Project";
import { YarnDependencyTypes as DependencyTypes } from "../Yarn";
import { FramerPackageJson, YarnCommandResult } from "../types";
export { DependencyTypes };
declare type Paths = Pick<ProjectPaths, "main" | "nodeModules" | "npmrc" | "packageJson" | "project" | "yarnCache" | "yarnLinkDir" | "yarnLock" | "yarnMutex" | "yarnrc">;
export interface PackageConfig {
    paths: Paths;
    packageJson?: Partial<FramerPackageJson>;
    npmrcTemplate?: string;
    builtInFramerVersion?: string | void;
}
export declare class Package {
    private readonly paths;
    private readonly yarn;
    private readonly framerLibraryManager;
    private packageJson;
    static load({ paths, packageJson, npmrcTemplate, builtInFramerVersion, }: PackageConfig): Promise<Package>;
    static prepare({ paths, npmrcTemplate }: {
        paths: Paths;
        npmrcTemplate?: string;
    }): Promise<void>;
    private constructor();
    readPackageName(reload?: boolean): Promise<string>;
    writePackageName(name: string): Promise<Readonly<FramerPackageJson>>;
    readPackageVersion(reload?: boolean): Promise<string>;
    writePackageVersion(version: string): Promise<Readonly<FramerPackageJson>>;
    readAuthor(reload?: boolean): Promise<string>;
    writeAuthor(author: string): Promise<Readonly<FramerPackageJson>>;
    readDisplayName(reload?: boolean): Promise<string>;
    writeDisplayName(displayName: string): Promise<Readonly<FramerPackageJson>>;
    install(...args: string[]): Promise<YarnCommandResult>;
    installFramer(version?: string): Promise<void>;
    publish(...args: string[]): Promise<YarnCommandResult>;
    readDependencies(reload?: boolean): Promise<Readonly<Pick<FramerPackageJson, "dependencies" | "devDependencies" | "peerDependencies">>>;
    addDependency(dependency: string, version?: string): Promise<YarnCommandResult>;
    addPeerDependency(dependency: string, version?: string): Promise<YarnCommandResult>;
    addDevDependency(dependency: string, version?: string): Promise<YarnCommandResult>;
    removeDependency(dependency: string): Promise<YarnCommandResult>;
    linkDependency(dependency: string): Promise<YarnCommandResult>;
    unlinkDependency(dependency: string): Promise<YarnCommandResult>;
    upgradeDependency(dependency: string, version?: string): Promise<YarnCommandResult>;
    info(packageName: string, info: string): Promise<YarnCommandResult>;
    check(): Promise<YarnCommandResult>;
    getLatestPublishedVersion(): Promise<string>;
    private read;
    private write;
    private invalidatePackageJson;
}
