import { CompilerConfig, Build, WatchHandle } from "../Compiler";
import { YarnCommandResult, FramerPackageJson } from "../types";
import { PackageConfig } from "../Package/Package";
import { ProjectPathsConfig, ProjectPaths } from "./Paths";
export { ProjectPaths };
export interface ProjectSetupConfig extends ProjectPathsConfig {
    npmrcTemplate?: string;
}
export interface ProjectConfig extends ProjectSetupConfig, Omit<PackageConfig, "paths"> {
    compiler?: Omit<CompilerConfig, "root">;
    builtInFramerVersion?: string;
}
export declare class Project {
    private readonly compiler;
    private readonly pkg;
    readonly path: string;
    readonly paths: ProjectPaths;
    static load(config: ProjectConfig): Promise<Project>;
    static prepareDir(config: ProjectSetupConfig): Promise<string>;
    static extract(projectPath: string): Promise<string>;
    private constructor();
    install(): Promise<YarnCommandResult>;
    installFramer(version: string): Promise<void>;
    addDependency(dependency: string, version?: string): Promise<YarnCommandResult>;
    addPeerDependency(dependency: string, version?: string): Promise<YarnCommandResult>;
    addDevDependency(dependency: string, version?: string): Promise<YarnCommandResult>;
    removeDependency(dependency: string): Promise<YarnCommandResult>;
    getLatestPublishedVersion(): Promise<string>;
    build(): Promise<Build>;
    buildDist(): Promise<Build>;
    publish({ version, packageName, displayName, access, }: {
        version?: string | null;
        packageName?: string;
        displayName?: string;
        access?: "restricted" | "public";
    }): Promise<YarnCommandResult>;
    watch(): WatchHandle;
    getDisplayName(): Promise<string>;
    getAuthor(): Promise<string>;
    getPackageName(): Promise<string>;
    getPackageVersion(): Promise<string>;
    getDependencies(): Promise<Pick<FramerPackageJson, "dependencies" | "peerDependencies" | "devDependencies">>;
    setDisplayName(name: string): Promise<FramerPackageJson>;
    setAuthor(author: string): Promise<FramerPackageJson>;
    setPackageName(name: string): Promise<FramerPackageJson>;
    setPackageVersion(version: string): Promise<FramerPackageJson>;
    private writeBuildOutputToDisk;
}
